@@ -29,7 +29,7 @@ import scipy
 from scipy import integrate
 from scipy import interpolate
 import math
-from pylal import lalconstants
+import lal
 import pdb
 import csv
 from glue.ligolw import ligolw, lsctables, array, param, utils, types
@@ -40,13 +40,13 @@ class XMLContentHandler(ligolw.LIGOLWContentHandler):
 	pass
 
 def Theta(eta, Mtot, t):
-	Tsun = lalconstants.LAL_MTSUN_SI #4.925491e-6
+	Tsun = lal.MTSUN_SI #4.925491e-6
 	theta = eta / (5.0 * Mtot * Tsun) * -t
         return theta
 
 def freq(eta, Mtot, t):
         theta = Theta(eta, Mtot, t)
-        Tsun = lalconstants.LAL_MTSUN_SI #4.925491e-6
+        Tsun = lal.MTSUN_SI #4.925491e-6
         f = 1.0 / (8.0 * Tsun * scipy.pi * Mtot) * (
                 theta**(-3.0/8.0) +
                 (743.0/2688.0 + 11.0 /32.0 * eta) * theta**(-5.0 /8.0) -
@@ -65,9 +65,9 @@ def Phase(eta, Mtot, t, phic = 0.0):
 
 def Amp(eta, Mtot, t):
         theta = Theta(eta, Mtot, t)
-        c = lalconstants.LAL_C_SI #3.0e10
-        Tsun = lalconstants.LAL_MTSUN_SI #4.925491e-6
-	Mpc = 1e6 * lalconstants.LAL_PC_SI #3.08568025e24
+        c = lal.C_SI #3.0e10
+        Tsun = lal.MTSUN_SI #4.925491e-6
+	Mpc = 1e6 * lal.PC_SI #3.08568025e24
         f = 1.0 / (8.0 * Tsun * scipy.pi * Mtot) * (theta**(-3.0/8.0))
         amp = - 4.0/Mpc * Tsun * c * (eta * Mtot ) * (Tsun * scipy.pi * Mtot * f)**(2.0/3.0);
         return amp
@@ -76,10 +76,12 @@ def waveform(m1, m2, fLow, fhigh, sampleRate):
         deltaT = 1.0 / sampleRate
         T = spawaveform.chirptime(m1, m2 , 4, fLow, fhigh)
         tc = -spawaveform.chirptime(m1, m2 , 4, fhigh)
-        t = numpy.arange(tc-T, tc, deltaT)
-	# avoid the numerical bug when calculating frequency f
-	if t[-1] < 1e-5:
-		t = t[:-2]
+	# the last sampling point of any waveform is always set 
+	# at abs(t) >= delta. this is to avoid ill-condition of 
+	# frequency when abs(t) < 1e-5
+	n_start = math.floor((tc-T) / deltaT + 0.5)
+	n_end = min(math.floor(tc/deltaT), -1)
+        t = numpy.arange(n_start, n_end+1, 1) * deltaT
         Mtot = m1 + m2
         eta = m1 * m2 / Mtot**2
         f = freq(eta, Mtot, t)
@@ -88,10 +90,10 @@ def waveform(m1, m2, fLow, fhigh, sampleRate):
         return amp, phase, f
 
 def sigmasq2(mchirp, fLow, fhigh, psd_interp):
-	c = lalconstants.LAL_C_SI #299792458
-	G = lalconstants.LAL_G_SI #6.67259e-11
-	M = lalconstants.LAL_MSUN_SI #1.98892e30
-	Mpc =1e6 * lalconstants.LAL_PC_SI #3.0856775807e22
+	c = lal.C_SI #299792458
+	G = lal.G_SI #6.67259e-11
+	M = lal.MSUN_SI #1.98892e30
+	Mpc =1e6 * lal.PC_SI #3.0856775807e22
 	#mchirp = 1.221567#30787
 	const = numpy.sqrt((5.0 * math.pi)/(24.*c**3))*(G*mchirp*M)**(5./6.)*math.pi**(-7./6.)/Mpc
 	return  const * numpy.sqrt(4.*integrate.quad(lambda x: x**(-7./3.) / psd_interp(x), fLow, fhigh)[0])
