@@ -22,9 +22,9 @@
 #
 # STATUS: reviewed with actions
 #
-# | Names                                          | Hash                                        | Date       |
-# | -------------------------------------------    | ------------------------------------------- | ---------- |
-# | Hanna, Cannon, Meacher, Creighton J, Robinet, Sathyaprakash, Messick, Dent, Blackburn | 7fb5f008afa337a33a72e182d455fdd74aa7aa7a    | 2014-11-05 |
+# | Names                                          | Hash                                        | Date       | Diff to Head of Master      |
+# | -------------------------------------------    | ------------------------------------------- | ---------- | --------------------------- |
+# | Hanna, Cannon, Meacher, Creighton J, Robinet, Sathyaprakash, Messick, Dent, Blackburn | 7fb5f008afa337a33a72e182d455fdd74aa7aa7a | 2014-11-05 |<a href="@gstlal_inspiral_cgit_diff/python/far.py?id=HEAD&id2=7fb5f008afa337a33a72e182d455fdd74aa7aa7a">far.py</a> |
 #
 # #### Action items
 #
@@ -845,7 +845,7 @@ class ThincaCoincParamsDistributions(snglcoinc.CoincParamsDistributions):
 		# lnP_signal(), and friends methods.
 		#
 
-		params.horizons = self.horizon_history.getdict(float(events[0].get_end()))
+		params.horizons = self.horizon_history.getdict(float(events[0].end))
 		# for instruments that provided triggers,
 		# use the trigger effective distance and
 		# SNR to provide the horizon distance.
@@ -889,8 +889,8 @@ class ThincaCoincParamsDistributions(snglcoinc.CoincParamsDistributions):
 				return NegInf
 			if lnP_noise > 0. and lnP_signal > 0.:
 				return PosInf
-		lnP_signal += math.log(.99)
-		lnP_noise += math.log(0.01)
+		lnP_signal += -0.010050335853501451	# math.log(.99)
+		lnP_noise += -4.6051701859880909	# math.log(0.01)
 		return max(lnP_signal, lnP_noise) + math.log1p(math.exp(-abs(lnP_signal - lnP_noise)))
 
 	def add_snrchi_prior(self, rates_dict, n, prefactors_range, df, inv_snr_pow = 4., verbose = False):
